@@ -135,10 +135,28 @@ read.slicerjson <- function(x,lps2ras=FALSE,na=NULL) {
     LPS=FALSE
     if (mydata$coordinateSystem == "LPS")
         LPS = TRUE
-    
+
+    orientation <- mydata$controlPoints[[1]]$orientation[[1]]
+    trafo <- diag(4)
+    trafo[1:3,1:3] <- matrix(orientation,3,3,byrow=T)
     cp <- mydata$controlPoints
     helpfun <- function(z) {
-        mat <- t(sapply(z$position,rbind))
+        nullcheck <-  z$positionStatus
+        nullcheck <- which(nullcheck == "undefined")
+        empty <- FALSE
+        if (length(nullcheck)) {
+            if (length(nullcheck)== length(z$position)) {
+                empty <- TRUE
+                mat <- matrix(NA,length(nullcheck),3)
+            } else {
+                
+            for (i in nullcheck)
+                 z$position[[i]] <- c(NA,NA,NA)
+            }
+        }
+        if (!empty)
+            mat <- t(sapply(z$position,rbind))
+
         labels <- z$label
         rownames(mat) <- labels
         return(mat)
@@ -150,7 +168,7 @@ read.slicerjson <- function(x,lps2ras=FALSE,na=NULL) {
         cp <- cp[[1]]
 
      if (LPS && lps2ras)
-         cp <- LPS2RAS(cp)
+         cp <- applyTransform(cp,trafo)
 
     if (!is.null(na)) {
         nas <- which(abs(cp) == na)
@@ -196,6 +214,9 @@ write.slicerjson <- function(x,filename=dataname,type=c("Fiducial","Curve","Clos
     if (coordinateSystem == "RAS")
         orientation <- c(1,0,0,0,1,0,0,0,1)
     position <- lapply(1:nrx, function(y) y <- x[y,] )
+    poschk <- which(as.logical(sapply(lapply(position,is.na),sum)))
+    if (length(poschk))
+        position[poschk] <- ""
     cp <- data.frame(id=as.character(1:nrx),label=mylabels,description=rep("",nrx),associatedNodeID=rep("",nrx))
     cp$position <- position
     cp$orientation <- lapply(1:nrx,function(x) x <- orientation)
@@ -203,6 +224,8 @@ write.slicerjson <- function(x,filename=dataname,type=c("Fiducial","Curve","Clos
     cp$locked <- FALSE
     cp$visibility <- rep(TRUE,nrx)
     cp$positionStatus <- rep("defined",nrx)
+    if (length(poschk))
+        cp$positionStatus[poschk] <- "undefined"
 
     markups <- data.frame(type=type,coordinateSystem=coordinateSystem,locked=TRUE,labelFormat="%N-%d")
     markups$controlPoints=list(cp)
