@@ -21,8 +21,8 @@ SEXP armaGinvCpp(SEXP matIn_, SEXP tol_) {
   
     }
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
