@@ -3,6 +3,6 @@
 
 #include <RcppArmadillo.h>
 
-RcppExport SEXP asymPerm() ;
+RcppExport SEXP asymPerm(SEXP asymr, SEXP groupsr, SEXP roundr);
 
 #endif
